package com.aidex.quartz.task;

import cn.hutool.http.HttpRequest;
import com.aidex.common.constant.Constants;
import com.aidex.common.constant.HttpStatus;
import com.aidex.common.core.redis.RedisCache;
import com.aidex.common.utils.StringUtils;
import com.aidex.framework.cache.ConfigUtils;
import com.aidex.system.domain.SysConfig;
import com.alibaba.fastjson2.JSONObject;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.concurrent.TimeUnit;

/**
 * @author ：ChenSir
 * @date ：Created in 2024/3/17 20:07
 * @description：由于access_token令牌有时效性，某些场景（模块或页面）需要线程常驻，那么需要mds长期有效，由于接口调用可以顺延mds的时效，建议定时器每隔5分钟请求一次本接口，确保mds不会过期。
 */
@Component("RefreshAccessTokenTask")
public class RefreshAccessTokenTask {

	protected static final Logger logger = LoggerFactory.getLogger(RefreshAccessTokenTask.class);

	@Autowired
	private RedisCache redisCache;

	private final String ACCESS_TOKEN_URL = "/api/user-service/lapp/v1/token/get";

	/**
	 * 刷新ACCESS_TOKEN
	 * @return token
	 */
	public String refreshAccessToken(){
		logger.info("刷新摄像头的ACCESS_TOKEN----------开始");
		String token = "";
		try{
			SysConfig sysConfigAppKey = ConfigUtils.getConfigByKey("sys.monitor.camera.appKey");
			SysConfig sysConfigSecret = ConfigUtils.getConfigByKey("sys.monitor.camera.secret");
			SysConfig sysConfigUrl=  ConfigUtils.getConfigByKey("sys.monitor.camera.url");
			if (sysConfigAppKey != null && sysConfigSecret != null && sysConfigUrl != null) {
				String appKey = sysConfigAppKey.getConfigValue();
				String secret = sysConfigSecret.getConfigValue();
				String url = sysConfigUrl.getConfigValue();
				JSONObject paramMap = new JSONObject();
				paramMap.put("appKey", appKey);
				paramMap.put("secret", secret);
				//链式构建请求
				String result = HttpRequest.post(url +ACCESS_TOKEN_URL).body(paramMap.toJSONString()).timeout(50000).execute().body();
				if (result != null) {
					JSONObject jsonObjec = JSONObject.parseObject(result);
					if (HttpStatus.SUCCESS == jsonObjec.getIntValue("code")){
						JSONObject accessToken = jsonObjec.getJSONObject("data");
						if (accessToken != null && StringUtils.isNotEmpty(accessToken.getString("accessToken"))){
							redisCache.setCacheObject(Constants.CAMERA_ACCESS_TOKEN_PREFIX, accessToken.getString("accessToken"), Constants.GPS_TOKEN_EXPIRATION, TimeUnit.DAYS);
						}else {
							logger.info("摄像头平台获取accessToken刷新结束,Http 摄像头平台获取accessToken初始化结束！-----{}", jsonObjec);
						}
					}else {
						logger.info("摄像头平台获取accessToken刷新结束,Http 请求结果错误！-----{}", jsonObjec);
					}
				}
			}
		}catch (Exception e){
			token = e.getLocalizedMessage();
		}
		logger.info("刷新摄像头的ACCESS_TOKEN----------结束");
		return token;
	}


}
