import AntModal from '@/components/pt/dialog/AntModal'
import { getSysAlarm, addSysAlarm, updateSysAlarm } from '@/api/system/sysAlarm'

export default {
  name: 'CreateForm',
  props: {
    statusOptions: {
      type: Array,
      required: true
    }

  },
  components: {
    AntModal

  },
  data () {
    return {
      open: false,
      closeDialog: true,
      spinning: false,
      delayTime: 100,
      labelCol: { span: 4 },
      wrapperCol: { span: 14 },
      loading: false,
      disabled: false,
      total: 0,
      id: undefined,
      formTitle: '添加报警信息',
      // 表单参数
      form: {},
      rules: {
        objectId: [{ required: true, message: '设备ID不能为空', trigger: 'blur' }],

        macId: [{ required: true, message: '设备号不能为空', trigger: 'blur' }],

        status: [{ required: true, message: '状态不能为空', trigger: 'blur' }]

      }
    }
  },
  filters: {},
  created () {},
  computed: {},
  watch: {},
  mounted () {},
  methods: {
    onClose () {
      this.open = false
      this.reset()
      this.$emit('close')
    },
    // 取消按钮
    cancel () {
      this.open = false
      this.reset()
      this.$emit('close')
    },
    // 表单重置
    reset () {
      this.form = {
        id: undefined,
        objectId: undefined,

        macId: undefined,

        fullName: undefined,

        macName: undefined,

        alarmime: undefined,

        addtime: undefined,

        speed: undefined,

        lat: undefined,

        lon: undefined,

        dir: undefined,

        describe: undefined,

        alarmType: undefined,

        classify: undefined,

        status: '0'

      }
    },
    /** 新增按钮操作 */
    handleAdd () {
      this.reset()
      this.open = true
      this.formTitle = '添加报警信息'
    },
    /** 修改按钮操作 */
    handleUpdate (row) {
      this.reset()
      this.open = true
      this.spinning = !this.spinning
      const sysAlarmId = row.id
      getSysAlarm(sysAlarmId).then(response => {
        this.form = response.data
        this.formTitle = '修改报警信息'
        this.spinning = !this.spinning
      })
    },
    /** 提交按钮 */
    submitForm: function (closeDialog) {
      this.closeDialog = closeDialog
      this.disabled = true
      this.$refs.form.validate(valid => {
        if (valid) {
          const saveForm = JSON.parse(JSON.stringify(this.form))
          if (this.form.id !== undefined) {
            updateSysAlarm(saveForm).then(response => {
              this.$message.success('更新成功', 3)
              this.open = false
              this.$emit('ok')
              this.$emit('close')
              this.disabled = false
            })
          } else {
            addSysAlarm(saveForm).then(response => {
              this.$message.success('新增成功', 3)
              this.open = false
              this.$emit('ok')
              this.$emit('close')
              this.disabled = false
            })
          }
        } else {
          this.disabled = false
          return false
        }
      })
    },
    back () {
      const index = '/system/sysalarm/index'
      this.$router.push(index)
    }

  }
}
